


import os
from paste.script.templates import Template, var
from paste.util.template import paste_script_template_renderer


class FalconTemplate(Template):

    _template_dir = 'falcon'
    summary = "A basic daixm microserivce based on falcon"
    vars = [
        var('version', 'Version (like 0.1)'),
        var('description', 'One-line description of the package'),
        var('long_description', 'Multi-line description (in reST)'),
        var('keywords', 'Space-separated keywords/tags'),
        var('author', 'Author name'),
        var('author_email', 'Author email'),
        var('url', 'URL of homepage'),
        ]

    template_renderer = staticmethod(paste_script_template_renderer)

    def post(self, command, output_dir, vars):
        os.rename('%s/gitignore' % output_dir, '%s/.gitignore' % output_dir)


class FlaskTemplate(Template):

    _template_dir = 'flask'
    summary = "A basic daixm microserivce based on flask"
    vars = [
        var('version', 'Version (like 0.1)'),
        var('description', 'One-line description of the package'),
        var('long_description', 'Multi-line description (in reST)'),
        var('keywords', 'Space-separated keywords/tags'),
        var('author', 'Author name'),
        var('author_email', 'Author email'),
        var('url', 'URL of homepage'),
        ]

    template_renderer = staticmethod(paste_script_template_renderer)

    def post(self, command, output_dir, vars):
        os.rename('%s/gitignore' % output_dir, '%s/.gitignore' % output_dir)



#!/usr/bin/env python
# coding: utf-8

import os
import sys
import atexit
import code


try:
    import IPython
    has_ipython = True
except ImportError:
    has_ipython = False


def hook_readline_hist():
    try:
        # Try to set up command history completion/saving/reloading
        import readline
    except ImportError:
        return

    # The place to store your command history between sessions
    histfile = os.environ["HOME"] + "/.ipython_history"
    readline.parse_and_bind('tab: complete')
    try:
        readline.read_history_file(histfile)
    except IOError:
        pass  # It doesn't exist yet.

    def savehist():
        try:
            readline.write_history_file(histfile)
        except:
            print 'Unable to save Python command history'
    atexit.register(savehist)


def get_banner():
    return 'Use it carefully!'


def pre_imports():
    # fill sth.
    return locals()


def plain_shell(user_ns):
    sys.exit(code.interact(banner=get_banner(), local=user_ns))


def ipython_shell(user_ns):
    if getattr(IPython, 'version_info', None) and IPython.version_info[0] >= 1:
        from IPython.terminal.ipapp import TerminalIPythonApp
        from IPython.terminal.interactiveshell import TerminalInteractiveShell
    else:
        from IPython.frontend.terminal.ipapp import TerminalIPythonApp
        from IPython.frontend.terminal.interactiveshell import TerminalInteractiveShell

    class DaixmIPythonApp(TerminalIPythonApp):
        def init_shell(self):
            self.shell = TerminalInteractiveShell.instance(
                config=self.config,
                display_banner=False, profile_dir=self.profile_dir,
                ipython_dir=self.ipython_dir, banner1=get_banner(), banner2='')
            self.shell.configurables.append(self)

    app = DaixmIPythonApp.instance()
    app.initialize()
    app.shell.user_ns.update(user_ns)
    sys.exit(app.start())


def main():
    hook_readline_hist()
    user_ns = pre_imports()
    use_plain_shell = not has_ipython or \
            '--plain' in sys.argv[1:]

    if use_plain_shell:
        plain_shell(user_ns)
    else:
        ipython_shell(user_ns)


if __name__ == '__main__':
    main()



# coding=utf8

import click
import subprocess

from family.deploy.aliyun import Listener

import ConfigParser, os

config = ConfigParser.ConfigParser()


@click.command()
@click.option('--slb', '-s', help='SLB id')
@click.option('--port', '-p', default='3000', help='port')
@click.option('--conf', '-c', help='configure')
def init_listener(slb, port, conf):
    config.readfp(open(conf))
    access_id = config.get('aliyun', 'access_id')
    access_secret = config.get('aliyun', 'access_secret')
    region = config.get('aliyun', 'region')
    listener = Listener(access_id, access_secret, region)
    listener.add_listener(slb, port)
    listener.start_listener(slb, port)



from setuptools import setup, find_packages
import sys, os

version = '0.2.2'

setup(name='family',
      version=version,
      description="Easy to create your microservice based on multiple python frameworks.",
      long_description="""\
""",
      keywords='microservice falcon flask',
      author='torpedoallen',
      author_email='torpedoallen@gmail.com',
      url='https://github.com/daixm/family',
      license='MIT',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'click',
          'PasteScript',
          'check-manifest',
          'aliyuncli',
          'aliyun-python-sdk-slb',
      ],
      entry_points="""
      [console_scripts]
      family-createapp=family.commands.createapp:create
      family-aliyun-init=family.commands.aliyun:init_listener
      family-aliyun-deploy=family.commands.aliyun:deploy
      [paste.paster_create_template]
      falcon = family.templates.basic:FalconTemplate
      flask = family.templates.basic:FlaskTemplate
      """,
      )



# coding=utf8

import click
import subprocess

@click.command()
@click.argument('project_name')
@click.option('--framework', '-f', default='falcon', help='framework')
def create(framework, project_name):
    cmd = 'paster create -t %s %s' % (framework, project_name)
    p = subprocess.Popen(cmd, shell=True)
    p.communicate()



# coding-utf8



'''
usage:

    * add slb listener
    * create and sync supervisor config
    * operate supervisor: reread, update, start, stop, restart, etc
'''


from aliyunsdkcore import client
from aliyunsdkslb.request.v20160520 import DescribeHealthStatusRequest
from aliyunsdkslb.request.v20160520 import CreateLoadBalancerHTTPListenerRequest
from aliyunsdkslb.request.v20160520 import StartLoadBalancerListenerRequest



class Listener(object):

    def __init__(self, access_id, access_secret, region):
        self.client = client.AcsClient(access_id, access_secret, region)

    def add_listener(self, slb, port):
        request = CreateLoadBalancerHTTPListenerRequest.CreateLoadBalancerHTTPListenerRequest()
        request.set_LoadBalancerId(slb)
        request.set_ListenerPort(port)
        request.set_BackendServerPort(port)
        request.set_Bandwidth(-1)
        request.set_StickySession('off')
        request.set_HealthCheck('off')
        return self.client.do_action(request)


    def start_listener(self, slb, port):
        request = StartLoadBalancerListenerRequest.StartLoadBalancerListenerRequest()
        request.set_LoadBalancerId(slb)
        request.set_ListenerPort(port)
        return self.client.do_action(request)
